// Frame that generates a demo of a depass.

// 	Name: DemoOne (class)
//	Author: Arjan Egges
//	Version: 1.0


import java.applet.*;
import java.awt.*;
import java.awt.event.*;
import com.sun.j3d.utils.applet.MainFrame;



class DemoOne extends Frame implements ActionListener, WindowListener {
    // Window Components
    Panel controlPanel;
    Panel canvasPanel;
    Button playpauseButton;
    Button stopButton;
                   
    AccidentUniverse au;
    
    // Variables for handling dynamics
    boolean playing = false;
    boolean playFromBegin = true;
    
  public DemoOne(){
  
      super("Demonstration [idle]");
      addWindowListener(this);
      
      // Introduction message
      Messenger.message("This demonstration shows an animation of a vehicle\n");
      Messenger.message("depassing another vehicle. Press play to run the demonstration\n");

      au = new AccidentUniverse();

      // Create a straightroad.
      Road straightRoad = new Road();
      straightRoad.textureOn = Messenger.properties.textureOn;
      au.add(straightRoad);
      
      // Create two cars and their corresponding eventchains
      FrenchDuck vehicle1 = new FrenchDuck();
      EventChain v1EventChain = new EventChain();
      FrenchDuck vehicle2 = new FrenchDuck();
      EventChain v2EventChain = new EventChain();
      
      // Create the event chain of vehicle 1.

      Event v1Event1 = new Event();
      v1Event1.name = "vehicle 1 changing lane to left";
      v1Event1.kind = Constant.CHANGELANE_LEFT;
      v1Event1.startPosX = -15.0f;
      v1Event1.startPosY = 1.5f;
      v1Event1.endPosX = -7.0f;
      v1Event1.endPosY = -1.5f;
      v1EventChain.addEvent(v1Event1);

      Event v1Event2 = new Event();
      v1Event2.name = "vehicle 1 depassing vehicle 2";
      v1Event2.startPosX = -7.0f;
      v1Event2.startPosY = -1.5f;
      v1Event2.endPosX = 7.0f;
      v1Event2.endPosY = -1.5f;
      v1EventChain.addEvent(v1Event2);
      
      Event v1Event3 = new Event();
      v1Event3.name = "vehicle 1 changing lane to right";
      v1Event3.kind = Constant.CHANGELANE_RIGHT;
      v1Event3.startPosX = 7.0f;
      v1Event3.startPosY = -1.5f;
      v1Event3.endPosX = 15.0f;
      v1Event3.endPosY = 1.5f;
      v1EventChain.addEvent(v1Event3);
      
      
      // Create the event chain of vehicle 2.
      Event v2Event = new Event();
      v2Event.name = "vehicle 2 driving straight";
      v2Event.kind = Constant.STRAIGHTROAD;
      v2Event.startPosX = -9.0f;
      v2Event.startPosY = 1.5f;
      v2Event.endPosX = 9.0f;
      v2Event.endPosY = 1.5f;
      v2EventChain.addEvent(v2Event);
      
      // Create the trajectories
      TrajectoryPlanner tp1 = new TrajectoryPlanner(v1EventChain);
      tp1.plan();
      vehicle1.setTrajectory(tp1.getTrajectory());
      
      TrajectoryPlanner tp2 = new TrajectoryPlanner(v2EventChain);
      tp2.plan();
      vehicle2.setTrajectory(tp2.getTrajectory());

      // Add both vehicles to the universe.
      au.add(vehicle1);
      au.add(vehicle2);     
      
      // Create the temporal values
      TemporalPlanner tp = new TemporalPlanner(au.getAccidentInfo());
      tp.plan();

      // Finalize
      au.createAll();
            
      // Create the canvas and the control panel
      this.setLayout(new FlowLayout()); 
      this.setSize(600,650);  
      canvasPanel = new Panel();
      controlPanel = new Panel();
      createControlPanel(controlPanel); 
      this.add(controlPanel);
      canvasPanel.add(au.getCanvas());
      this.add(canvasPanel);
      this.show();
   }
    
    private void createControlPanel(Panel p) {
       stopButton = new Button("Stop");
       playpauseButton = new Button("Play");
              
       p.add(stopButton);
       p.add(playpauseButton);
               
       stopButton.addActionListener (this);
       playpauseButton.addActionListener (this);
    }    

    // Button event handling
    public void actionPerformed (ActionEvent event) {
      if (event.getSource() == playpauseButton) {
          if (!playing) {
            setTitle("Demonstration [running]");
            playing = true;
            playpauseButton.setLabel("Pause");
            if (playFromBegin)
               au.play();
            else
               au.resume();
          } else {
             setTitle("Demonstration [paused]");
             au.pause();
             playFromBegin = false;
             playing = false;
             playpauseButton.setLabel("Play");
          }
      } else if (event.getSource() == stopButton) {
         setTitle("Demonstration [idle]");
         au.stop();
         playing = false;
         playFromBegin = true;
         playpauseButton.setLabel("Play");
      }  
    }   
    
    // Additional methods for  window event handling.
    
    public void windowClosing( WindowEvent event ) {
       Messenger.message("End of demonstration...\n");
       dispose();
    }
   
    public void windowClosed( WindowEvent event ) {
    }
   
    public void windowDeiconified( WindowEvent event ) {}
   
    public void windowIconified( WindowEvent event ) {}
   
   
public void windowDeactivated( WindowEvent event ) {}
   
    public void windowActivated( WindowEvent event ) {}
   
    public void windowOpened( WindowEvent event ) {}
}


   