// This class plans the initial start and end positions of the vehicles

// 	Name: PositionPlanner (class)
//	Author: Arjan Egges
//	Version: 1.0

class PositionPlanner implements Planner {

   // Private members
   private AccidentInfo ainfo;
   private boolean errorsDetected;
   private int eastCount = 0;
   private int westCount = 0;
   private int northCount = 0;
   private int southCount = 0;
   
   // Constructor
   public PositionPlanner(AccidentInfo ai) {
      ainfo = ai;
      errorsDetected = false;
   }
   
   // Starts the planning process
   public void plan() {
      // Count the number of vehicles in every direction.
      for (int i = 0; i< ainfo.getDynamicAmount(); i++) {
         DynamicInfo di = ainfo.getDynamicInfo(i);
         if (di.initDirection == DynamicInfo.EAST)
            eastCount++;
         else if (di.initDirection == DynamicInfo.WEST)
            westCount++;
         else if (di.initDirection == DynamicInfo.NORTH)
            northCount++;
         else
            southCount++;
      }
      
      if (eastCount > 3 || westCount > 3 || northCount > 3 || southCount > 3) {
         Messenger.message("Too many dynamic objects in one direction.\n");
         errorsDetected = true;
         return;
      } 
      
      eastCount = 0;
      westCount = 0;
      northCount = 0;
      southCount = 0;
      
      int actorInd = -1;
      int victimInd = -1;
      
      if (ainfo.getCollisionInfoAmount() != 0) {
         CollisionInfo ci = ainfo.getCollisionInfo(0);
         if (ci.victimPart == Constant.REAR) {
            // Rear accident
            victimInd = ci.victimIndex;
            ainfo.getDynamicInfo(victimInd).startPoint = 26.0f;
            ainfo.getDynamicInfo(victimInd).endPoint = 14.0f;
            actorInd = ci.actorIndex;
            ainfo.getDynamicInfo(actorInd).startPoint = 32.0f;
            ainfo.getDynamicInfo(actorInd).endPoint = 8.0f;
         }
      }
      
      // Place all the other vehicles
      for (int i = 0; i< ainfo.getDynamicAmount(); i++) {
         if (i != actorInd && i != victimInd) {
            DynamicInfo di = ainfo.getDynamicInfo(i);
            int currCount;
            if (di.initDirection == DynamicInfo.EAST) {
               eastCount++;
               currCount = eastCount;
            } else if (di.initDirection == DynamicInfo.WEST) {
               westCount++;
               currCount = westCount;
            } else if (di.initDirection == DynamicInfo.NORTH) {
               northCount++;
               currCount = northCount;
            } else {
               southCount++;
               currCount = southCount;
            }
            
            if (currCount == 1) {
               di.startPoint = 20.0f;
               di.endPoint = 20.0f;
            } else if (currCount == 2) {
               di.startPoint = 26.0f;
               di.endPoint = 14.0f;
            } else {
               di.startPoint = 32.0f;
               di.endPoint = 8.0f;
            }
         }  
      }
   }
   
   // Returns true if there are errors detected
   public boolean errors() {
      return errorsDetected;
   }
}