// This planner tries to fill in unknown values in the accident info object

// 	Name: PrePlanner (class)
//	Author: Arjan Egges
//	Version: 1.0


class PrePlanner implements Planner {
   
   // private members
   private AccidentInfo ainfo;
   
   public PrePlanner(AccidentInfo ai) {
      ainfo = ai;
   }
   
   public void plan() {
      if (ainfo.getCollisionInfoAmount() == 0) {
         Messenger.message("No accident modeling required.\n");
         fillInUnknownDirections();
         return;
      }
      fillInUnknownValues();
   }
   
   private void fillInUnknownValues() {

      // Plan the first accident
      CollisionInfo cinfo = ainfo.getCollisionInfo(0);
      DynamicInfo actorInfo = ainfo.getDynamicInfo(cinfo.actorIndex);
      DynamicInfo victimInfo = ainfo.getDynamicInfo(cinfo.victimIndex);
      
      // If the direction of the victim and the part of the victim are unknown
      if (cinfo.victimPart == Constant.UNKNOWN_PART && victimInfo.initDirection == DynamicInfo.UNKNOWN_DIRECTION) {
         victimInfo.initDirection = DynamicInfo.NORTH;
         cinfo.victimPart = Constant.LEFTSIDE;

      // If only the direction is unknown
      } else if (victimInfo.initDirection == DynamicInfo.UNKNOWN_DIRECTION) {
         if (cinfo.victimPart == Constant.FRONT)
            victimInfo.initDirection = DynamicInfo.WEST;
         else if (cinfo.victimPart == Constant.LEFTSIDE)
            victimInfo.initDirection = DynamicInfo.NORTH;
         else if (cinfo.victimPart == Constant.RIGHTSIDE)
            victimInfo.initDirection = DynamicInfo.SOUTH;
         else if (cinfo.victimPart == Constant.REAR)
            victimInfo.initDirection = DynamicInfo.NORTH;

      // If only the victim part is unknown
      } else if (cinfo.victimPart == Constant.UNKNOWN_PART) {
         if (victimInfo.initDirection == DynamicInfo.WEST)
            cinfo.victimPart = Constant.LEFTSIDE;
         else if (victimInfo.initDirection == DynamicInfo.NORTH)
            cinfo.victimPart = Constant.LEFTSIDE;
         else if (victimInfo.initDirection == DynamicInfo.SOUTH)
            cinfo.victimPart = Constant.RIGHTSIDE;
         else if (victimInfo.initDirection == DynamicInfo.EAST)
            cinfo.victimPart = Constant.REAR;
      }
      
      fillInUnknownDirections();

      // Plan the rest of the unknown values for the parts
      for (int i=0; i<ainfo.getCollisionInfoAmount(); i++) {
         if (ainfo.getCollisionInfo(i).actorPart == Constant.UNKNOWN_PART)
            ainfo.getCollisionInfo(i).actorPart = Constant.FRONT;
         if (ainfo.getCollisionInfo(i).victimPart == Constant.UNKNOWN_PART)
            ainfo.getCollisionInfo(i).victimPart = Constant.FRONT;
      }
        
   }
   
   public void fillInUnknownDirections() {
      // The first actor direction is east; if not known
      if (ainfo.getDynamicInfo(ainfo.getCollisionInfo(0).actorIndex).initDirection == DynamicInfo.UNKNOWN_DIRECTION)
         ainfo.getDynamicInfo(ainfo.getCollisionInfo(0).actorIndex).initDirection = DynamicInfo.EAST;
         
      // Fill in all unknown directions
      for (int i=0; i<ainfo.getDynamicAmount(); i++) {
         if (ainfo.getDynamicInfo(i).initDirection == DynamicInfo.UNKNOWN_DIRECTION)
            ainfo.getDynamicInfo(i).initDirection = DynamicInfo.EAST;
      }                     
   }
   
   public boolean errors() {
      return false;
   }
}