// Frame for the properties window

//	Name: PropertyFrame (class)
//	Author: Arjan Egges
//	Version: 1.0

import java.applet.Applet;
import java.awt.*;
import java.awt.event.*;
import java.awt.FlowLayout;

import com.sun.j3d.utils.applet.MainFrame;
import com.sun.j3d.utils.universe.*;
import javax.media.j3d.*;


class PropertyFrame extends Frame implements ActionListener, WindowListener {

   // Window components
   Checkbox useTextures;
   Checkbox createEnv;
   TextField duration;
   
   // Accident planning properties
   TextField initCRadius;
   TextField tPrecision;
   TextField sPerc;
   
   Button okButton;
   Button cancelButton;
   
   public PropertyFrame() {
      super("Properties");
      addWindowListener(this);
      setResizable(false);
      FlowLayout fl = new FlowLayout();
      fl.setAlignment(FlowLayout.RIGHT);
      this.setLayout(fl);
      this.setSize(275,240);
      
      useTextures = new Checkbox("Use Textures",Messenger.properties.textureOn);
      add(useTextures);
      
      createEnv = new Checkbox("Draw background",Messenger.properties.createEnvironment);
      add(createEnv);
      
      add(new Label("Duration (seconds): "));
      duration = new TextField(String.valueOf(Messenger.properties.duration),6);
      add(duration);
      
      add(new Label("Init search radius (0 - 14):"));
      initCRadius = new TextField(String.valueOf(Messenger.properties.initCircleRadius),6);
      add(initCRadius);
      
      
      add(new Label("Trajectory precision (1 - 100):"));
      tPrecision = new TextField(String.valueOf(Messenger.properties.trajectoryPrecision),6);
      add(tPrecision);

      add(new Label("Stop percentage (0 - 50):"));
      sPerc = new TextField(String.valueOf(Messenger.properties.stopPerc),6);
      add(sPerc);
      
      
      
      okButton = new Button("Ok");
      okButton.addActionListener(this);
      add(okButton);
      cancelButton = new Button("Cancel");
      cancelButton.addActionListener(this);
      add(cancelButton);
     
      this.show(); 
   }
   
   private void setProperties() {
         
   }
   
    public void actionPerformed(ActionEvent event) {
       if (event.getSource() == okButton) {
         try {
             Messenger.properties.textureOn = useTextures.getState();
             int dur = Integer.decode(duration.getText()).intValue();
             if (dur < 0) {
                Messenger.message("Invalid value entered for duration (enter a value larger than 0).\n");
                return;
             }             
             Messenger.properties.duration = dur;
             Messenger.properties.createEnvironment = createEnv.getState();
             float initCR = Float.parseFloat(initCRadius.getText());
             if (initCR < 0.0f || initCR > 14.0f) {
                Messenger.message("Invalid value entered for init circle radius (enter a value between 0 and 14).\n");
                return;
             }
             Messenger.properties.initCircleRadius = initCR;
             int tprec = Integer.parseInt(tPrecision.getText());
             if (tprec < 1 || tprec > 100) {
                Messenger.message("Invalid value entered for trajectory precision (enter a value between 1 and 100).\n");
                return;
             }
             Messenger.properties.trajectoryPrecision = tprec;
             float sp = Float.parseFloat(sPerc.getText());
             if (sp < 0 || sp > 50) {
                Messenger.message("Invalid value entered for stop percentage (enter a value between 0 and 50).\n");
                return;
             }
             Messenger.properties.stopPerc = sp;
          } catch(Exception e) {
             Messenger.message("Invalid value entered.\n");
             return;
         }
         dispose();
       } else if (event.getSource() == cancelButton) 
          dispose();
          
    }
    
    public void windowClosing( WindowEvent event ) {
       dispose();
    }
   
   
    public void windowClosed( WindowEvent event ) {
    }
   
    public void windowDeiconified( WindowEvent event ) {}
   
    public void windowIconified( WindowEvent event ) {}
   
   
public void windowDeactivated( WindowEvent event ) {}
   
    public void windowActivated( WindowEvent event ) {}
   
    public void windowOpened( WindowEvent event ) {}
}