// This class creates a roadsign with a specified text.

// 	Name: Roadsign (class)
//	Author: Arjan Egges
//	Version: 1.0


import java.awt.Font;
import com.sun.j3d.utils.geometry.*;
import javax.media.j3d.*;
import javax.vecmath.*;

class Roadsign implements AccidentObject {

   // Properties
   public float xPos;
   public float yPos;
   public float height;
   public String text;
   
   // Private members
   private TransformGroup signGeo;
   
   // Constructors
   public Roadsign() {
      xPos = 0.0f;
      yPos = -3.2f;
      height = 2.5f;
      text = new String("Roadsign");
   }
   
   public Roadsign(String textOnSign) {
      xPos = 0.0f;
      yPos = -3.2f;
      height = 2.5f;
      text = new String(textOnSign);
   }
   
   // Creates the geometry of the Roadsign object
   public void createGeometry() {
      Transform3D translate = new Transform3D();
      translate.set(new Vector3f(xPos,0.0f,yPos));
      signGeo = new TransformGroup(translate);
      
      // Create a cylinder
      Appearance cylAppear = new Appearance();
      Color3f eColor    = new Color3f(0.0f, 0.0f, 0.0f);
      Color3f sColor    = new Color3f(1.0f, 1.0f, 1.0f);
      Color3f oColor    = new Color3f(0.5f, 0.5f, 0.5f);
      
      Material cylMat = new Material(oColor, eColor, oColor, sColor, 100.0f);
      cylMat.setLightingEnable(true);
      cylAppear.setMaterial(cylMat);
      translate.set(new Vector3f(0.0f, height/2.0f, 0.0f));
      TransformGroup cylTrans = new TransformGroup(translate);
      signGeo.addChild(cylTrans);
      cylTrans.addChild(new Cylinder(0.03f,height,cylAppear));
      
      // Create a box
      Appearance boxAppear = new Appearance();
      eColor    = new Color3f(0.0f, 0.0f, 0.0f);
      sColor    = new Color3f(1.0f, 1.0f, 1.0f);
      oColor    = new Color3f(0.1f, 0.8f, 0.3f);
      
      Material boxMat = new Material(oColor, eColor, oColor, sColor, 100.0f);
      boxMat.setLightingEnable(true);
      boxAppear.setMaterial(boxMat);
      translate.set(new Vector3f(0.0f, height-0.21f, 0.0f));
      TransformGroup boxTrans = new TransformGroup(translate);
      signGeo.addChild(boxTrans);
      boxTrans.addChild(new Box(1.2f,0.2f,0.05f,Box.GENERATE_NORMALS,boxAppear));
      
      // Add the text
      Text2D text2D = new Text2D(text, new Color3f(1.0f, 1.0f, 1.0f), "Times",50, Font.BOLD);
      translate.set(new Vector3f(-1.15f, height-0.3f, 0.06f));
      TransformGroup textTrans = new TransformGroup(translate);
      signGeo.addChild(textTrans);
      textTrans.addChild(text2D);
   }
   
   // Returns the geometry of the Roadsign object
   public TransformGroup getGeometry() {
      return signGeo;
   }
   
   // The id is defines as the text on the roadsign
   public String getId() {
      return text;
   }
   
   // Returns the collision radius
   public float getCollisionRadius() {
      return 0.03f;
   }

   // Returns the x position of the roadsign
   public float getXPos() {
      return xPos;
   }
   
   // Returns the y position of the roadsign
   public float getYPos() {
      return yPos;
   }

}

