// This class creates a stop sign.

// 	Name: StopSign (class)
//	Author: Arjan Egges
//	Version: 1.0


import java.awt.Font;
import com.sun.j3d.utils.geometry.*;
import javax.media.j3d.*;
import javax.vecmath.*;

class StopSign implements AccidentObject {

   // Properties
   public float xPos;
   public float yPos;
   public String id;
   
   // Private members
   private TransformGroup ssGeo;
   
   // Constructor
   public StopSign() {
      xPos = 0.0f;
      yPos = 0.0f;
      id = "stop sign";
   }
   
   // Creates the geometry of the StopSign
   public void createGeometry() {
      Transform3D translate = new Transform3D();
      translate.set(new Vector3f(xPos,0.0f,yPos));
      ssGeo = new TransformGroup(translate);
      
      // Add a cylinder
      Appearance cylAppear = new Appearance();
      Color3f eColor    = new Color3f(0.0f, 0.0f, 0.0f);
      Color3f sColor    = new Color3f(1.0f, 1.0f, 1.0f);
      Color3f oColor    = new Color3f(0.5f, 0.5f, 0.5f);
      
      Material cylMat = new Material(oColor, eColor, oColor, sColor, 100.0f);
      cylMat.setLightingEnable(true);
      cylAppear.setMaterial(cylMat);
      translate.set(new Vector3f(0.0f, 2.0f, 0.0f));
      TransformGroup cylTrans = new TransformGroup(translate);
      ssGeo.addChild(cylTrans);
      cylTrans.addChild(new Cylinder(0.03f,4.0f,cylAppear));
  
      // Create the stop sign, a triangle fan array
      TriangleFanArray tfa;
      Point3f coords[] = new Point3f[10];
      int stripCounts[] = {10};
      
      float scale = 0.6f;
      
      // Define the coordinates
      coords[0] = new Point3f(0.0f, 0.0f, 0.0f);
      coords[1] = new Point3f(scale,scale/2.0f, 0.0f);
      coords[2] = new Point3f(scale/2.0f,scale, 0.0f);
      coords[3] = new Point3f(-scale/2.0f,scale, 0.0f);
      coords[4] = new Point3f(-scale,scale/2.0f, 0.0f);
      coords[5] = new Point3f(-scale,-scale/2.0f, 0.0f);
      coords[6] = new Point3f(-scale/2.0f,-scale, 0.0f);
      coords[7] = new Point3f(scale/2.0f,-scale, 0.0f);
      coords[8] = new Point3f(scale,-scale/2.0f, 0.0f);
      coords[9] = new Point3f(scale,scale/2.0f, 0.0f);
      
      tfa = new TriangleFanArray(10,TriangleFanArray.COORDINATES,stripCounts);
      tfa.setCoordinates(0, coords);
      
      // Create the appearance.
      Appearance pAppear = new Appearance();
      eColor    = new Color3f(0.0f, 0.0f, 0.0f);
      sColor    = new Color3f(1.0f, 0.0f, 0.0f);
      oColor    = new Color3f(1.0f, 0.0f, 0.0f);
      
      Material pMat = new Material(oColor, eColor, oColor, sColor, 100.0f);
      pMat.setLightingEnable(true);
      pAppear.setMaterial(pMat);
      PolygonAttributes polyAppear = new PolygonAttributes();
      polyAppear.setCullFace(PolygonAttributes.CULL_NONE);
      pAppear.setPolygonAttributes(polyAppear);
      
      
      
      // Find the turning angle
      float angle = 0.0f;
      if (xPos < 0 && yPos > 0)
         angle = -(float)Math.PI/2.0f;
      else if (xPos < 0 && yPos < 0)
         angle = (float)Math.PI;
      else if (xPos > 0 && yPos < 0)
         angle = (float)Math.PI/2.0f;
      Transform3D rotate = new Transform3D();
      rotate.rotY(angle);
      translate.set(new Vector3f(0.0f, 3.5f, 0.03f));
      rotate.mul(translate);
      
      // Create a transformgroup
      TransformGroup pannTrans = new TransformGroup(rotate);
      ssGeo.addChild(pannTrans);
      Shape3D sign = new Shape3D();
      sign.setGeometry(tfa);
      sign.setAppearance(pAppear);
      pannTrans.addChild(sign);
      
      // Add the text
      Text2D text2D = new Text2D("STOP", new Color3f(1.0f, 1.0f, 1.0f), "Times",80, Font.BOLD);
      translate.set(new Vector3f(-0.5f,-0.15f, 0.01f));
      TransformGroup textTrans = new TransformGroup(translate);
      pannTrans.addChild(textTrans);
      textTrans.addChild(text2D);
      
   }
   
   // Returns the geometry of the StopSign
   public TransformGroup getGeometry() {
      return ssGeo;
   }
   
   // Returns the id
   public String getId() {
      return id;
   }
   
   // Returns the collision radius
   public float getCollisionRadius() {
      return 0.03f;
   }

   // Returns the x position
   public float getXPos() {
      return xPos;
   }
   
   // Returns the y position
   public float getYPos() {
      return yPos;
   }

}

