//   A class to create a simple textured plane.

// 	Name: TexturedXYPlane (class)
//	Author: Arjan Egges
//	Version: 1.0


import com.sun.j3d.utils.image.TextureLoader;
import javax.media.j3d.*;
import javax.vecmath.*;

public class TexturedXYPlane extends Shape3D {
   
   // Private members
   private float planeXLength;
   private float planeYLength;
 
   // Constructor
   TexturedXYPlane(String filename,float xl, float yl) {
      planeXLength = xl;
      planeYLength = yl;
      if (NewTextureLoader.getImageObserver() == null)
         System.out.println("call NewTextureLoader.setImageObserver()");
      this.setGeometry(createGeometry());
      if(filename != "")
         this.setAppearance(createAppearance(filename));
   }    

   // Create the Textured XY plane
   Geometry createGeometry(){

      QuadArray plane = new QuadArray(4, GeometryArray.COORDINATES
| GeometryArray.TEXTURE_COORDINATE_2);
      Point3f p = new Point3f(-planeXLength/2.0f,  planeYLength/2.0f,  0.0f);
      plane.setCoordinate(0, p);
      p.set(-planeXLength/2.0f, -planeYLength/2.0f,  0.0f);
      plane.setCoordinate(1, p);
      p.set(planeXLength/2.0f, -planeYLength/2.0f,  0.0f);
      plane.setCoordinate(2, p);
      p.set(planeXLength/2.0f,  planeYLength/2.0f,  0.0f);
      plane.setCoordinate(3, p);

      Point2f q = new Point2f( 0.0f,  planeYLength);
      plane.setTextureCoordinate(0, q);
      q.set(0.0f, 0.0f);
      plane.setTextureCoordinate(1, q);
      q.set(planeXLength, 0.0f);
      plane.setTextureCoordinate(2, q);
      q.set(planeXLength, planeYLength);
      plane.setTextureCoordinate(3, q);

      return plane;
   }

   // Create the appearance
   Appearance createAppearance(String filename) {

      Appearance appear = new Appearance();

      Messenger.message("Attempt to load file: "+filename+"...");
      TextureLoader loader = new NewTextureLoader(filename);
      ImageComponent2D image = loader.getImage();

      if(image == null) {
         Messenger.message("load failed for texture: "+filename+"\n");
      }
else {
         Messenger.message("succeeded\n");
      }
   
      // can't use parameterless constuctor
      Texture2D texture = new Texture2D(Texture.BASE_LEVEL, Texture.RGB,
image.getWidth(), image.getHeight());
      texture.setImage(0, image);
      texture.setEnable(true);
      texture.setMagFilter(Texture.NICEST);
      appear.setTexture(texture);
      return appear;
   }
}

