// This class defines the geometry of a tree object

// 	Name: Tree (class)
//	Author: Arjan Egges
//	Version: 1.0


import com.sun.j3d.utils.geometry.*;
import NewTextureLoader;
import javax.media.j3d.*;
import javax.vecmath.*;
import com.sun.j3d.utils.image.TextureLoader;

class Tree implements AccidentObject {

   // Public properties
   public float xPos;
   public float yPos;
   public String id;
   
   // Private members   
   private TransformGroup treeGroup;
   private float collisionRad = 0.5f;
   
   // Constructor
   public Tree() {
      xPos = 0.0f;
      yPos = 0.0f;
      id = "tree";
   }
   
   // Creates the geometry of the Tree
   public void createGeometry() {
      Transform3D translate = new Transform3D();
      translate.set(new Vector3f(xPos,0.0f,yPos));
      treeGroup = new TransformGroup(translate);
      
      // Add a cylinder
      Appearance cylAppear = new Appearance();
      Color3f eColor    = new Color3f(0.0f, 0.0f, 0.0f);
      Color3f sColor    = new Color3f(1.0f, 1.0f, 1.0f);
      Color3f oColor    = new Color3f(0.6f, 0.3f, 0.1f);
      
      Material cylMat = new Material(oColor, eColor, oColor, sColor, 100.0f);
      cylMat.setLightingEnable(true);
      cylAppear.setMaterial(cylMat);
      translate.set(new Vector3f(0.0f, 2.5f, 0.0f));
      TransformGroup cylTrans = new TransformGroup(translate);
      treeGroup.addChild(cylTrans);
      Cylinder c = new Cylinder(0.5f,5.0f,cylAppear);
      cylTrans.addChild(c);
      
      // Add a sphere
      Appearance sphereAppear = new Appearance();
      eColor    = new Color3f(0.0f, 0.0f, 0.0f);
      sColor    = new Color3f(1.0f, 1.0f, 1.0f);
      oColor    = new Color3f(0.1f, 0.3f, 0.1f);
      
      Material sphereMat = new Material(oColor, eColor, oColor, sColor, 100.0f);
      sphereMat.setLightingEnable(true);
      sphereAppear.setMaterial(sphereMat);
      translate.set(new Vector3f(0.0f, 7.5f, 0.0f));
      TransformGroup sphereTrans = new TransformGroup(translate);
      treeGroup.addChild(sphereTrans);
      sphereTrans.addChild(new Sphere(3.0f, sphereAppear));
      
      // Add a cone
      translate.set(new Vector3f(0.0f, 10.8f, 0.0f));
      TransformGroup coneTrans = new TransformGroup(translate);
      treeGroup.addChild(coneTrans);
      coneTrans.addChild(new Cone(2.52f, 3.4f, Cone.GENERATE_NORMALS,sphereAppear));
      
      

   }
   
   // Returns the geometry of the Tree
   public TransformGroup getGeometry() {
      return treeGroup;
   }
   
   // Returns the collision radius
   public float getCollisionRadius() {
      return collisionRad;
   }
   
   // Returns the id
   public String getId() {
      return id;
   }
   
   // Returns the x position
   public float getXPos() {
      return xPos;
   }
   
   // Returns the y position
   public float getYPos() {
      return yPos;
   }
   
}