// Base class for the automatic generation of accident simulations

// 	Name: accSimulator (class)
//	Author: Arjan Egges
//	Version 1.0

import java.applet.Applet;
import java.awt.*;
import java.awt.event.*;
import java.awt.FlowLayout;
import com.sun.j3d.utils.applet.MainFrame;
import com.sun.j3d.utils.universe.*;
import javax.media.j3d.*;
import java.io.*;


public class accSimulator extends Frame implements ActionListener, WindowListener {

    // Window Components
    Panel controlPanel;
    Panel canvasPanel;
    Button playpauseButton;
    Button stopButton;
    MenuBar mb;
    Menu simulation;
    MenuItem loadAD;
    MenuItem parseDescription;
    MenuItem createSimulation;
    MenuItem exitAppl;
    Menu edit;
    MenuItem enterText;
    MenuItem properties;
    Menu demo;
    MenuItem demoOne;
    MenuItem demoTwo;
    Menu help;
    MenuItem about;
    MenuItem generalHelp;
    TextArea messageWin;
     
    // Variables containing properties and accident data.
    private String parseText = "";
    private AccidentUniverse au;
    private boolean errors = false;
    
    public accSimulator (String argv[]){
      
      super("Accident Simulator [none]");
      addWindowListener(this);
      
      // Create the control panel and the message window
      this.setLayout(new FlowLayout()); 
      this.setSize(600,350);  
      createMenuBar();
      messageWin = new TextArea("",18,80,TextArea.SCROLLBARS_VERTICAL_ONLY);
      messageWin.setSize(600,300);
      messageWin.setEditable(false);
      add(messageWin);
      this.show();
      
      // Set initial text in Textfield
      message("Welcome to the accident simulator\n");
      message("Author: Arjan Egges\n");
      message("Version: 1.0\n");
      message("=================================\n");
    }
    
    public void message(String text) {
       if (text.startsWith("#parsetext#",0)) {
          parseText = text.substring(11,text.length());
          messageWin.append("Accident description changed.\n");
       } else
          messageWin.append(text);
       messageWin.setCaretPosition(10000);
    }
    
    private void createMenuBar() {
    
       mb = new MenuBar();
       
       simulation = new Menu("Simulation");
       loadAD = new MenuItem("Load AD");
       loadAD.addActionListener(this);
       parseDescription = new MenuItem("Parse AD");
       parseDescription.addActionListener(this);
       createSimulation = new MenuItem("Create simulation");
       exitAppl = new MenuItem("Exit");
       createSimulation.addActionListener(this);
       exitAppl.addActionListener(this);
       simulation.add(loadAD);
       simulation.add(parseDescription);
       simulation.add(createSimulation);
       simulation.add(exitAppl);
       mb.add(simulation);
       
       edit = new Menu("Edit");
       properties = new MenuItem("Properties");
       properties.addActionListener(this);
       enterText = new MenuItem("Accident description (AD)");
       enterText.addActionListener(this);
       edit.add(enterText);
       edit.add(properties);
       mb.add(edit);
       
       demo = new Menu("Demo");
       demoOne = new MenuItem("Demonstration 1");
       demoOne.addActionListener(this);
       demoTwo = new MenuItem("Demonstration 2");
       demoTwo.addActionListener(this);
       demo.add(demoOne);
       demo.add(demoTwo);
       mb.add(demo);
       
       help = new Menu("Help");
       about = new MenuItem("About...");
       about.addActionListener(this);
       help.add(about);
       generalHelp = new MenuItem("General help");
       generalHelp.addActionListener(this);
       help.add(generalHelp);
       mb.add(help);
       mb.setHelpMenu(help);
       
       this.setMenuBar(mb);      
    }
    
    public void parseDescr() {
       FormalismParser fp = new FormalismParser();
       fp.parse(parseText);
       errors = fp.errors();
       au = fp.getUniverse();
    }
    
    public void simulate() {
         message("Creating simulation...\n");
         parseDescr();
         if (errors)  {
            message("Could not create simulation due to parsing errors.\n");
            return;
         }
         // Plan the accident.
         AccidentPlanner planner = new AccidentPlanner(au.getAccidentInfo());
         planner.plan();
         if (planner.errors()) {
            message("Unable to plan accident. Aborting simulation.\n");
            return;
         }
         new Simulation(au);    
    }
    
    public void readParseFile() {
       FileDialog fd = new FileDialog(this, "Load Accident Description", FileDialog.LOAD);
       fd.show();
       String filename = ""+fd.getDirectory() + fd.getFile();
       if (fd.getFile() == null)
          return;
       message("Loading file: "+filename+"...");
       BufferedReader hfile;
       try {
          hfile = new BufferedReader(new FileReader(filename));
       } catch (Exception e) {
          message("failed!\n");
          message("Exception: "+e.toString());
          return;
       }
       parseText = "";
       try {
          while (hfile.ready()) {
             parseText = parseText + hfile.readLine() + "\n";
          }
       } catch (Exception e) {}
       message("done.\n");
       this.setTitle("Accident Simulator ["+fd.getFile()+"]");

    }
    
    
    // Event handling
    public void actionPerformed (ActionEvent event) {
      // Menu bar event handling
      if (event.getSource() == enterText) {
         new AccSimTextEditor(parseText);
      } else if (event.getSource() == loadAD) {
         readParseFile();
      } else if (event.getSource() == parseDescription) {
         parseDescr();
      } else if (event.getSource() == createSimulation) {
         simulate();
      } else if (event.getSource() == exitAppl) {
         System.exit(0);
      } else if (event.getSource() == properties) {
         new PropertyFrame();
      } else if (event.getSource() == demoOne) {
         new DemoOne();
      } else if (event.getSource() == demoTwo) {
         new DemoTwo();
      } else if (event.getSource() == about) {
         message("Accident Simulator version 1.0\n");
         message("Created by: Arjan Egges\nISMRA, Caen (France) 2000\n");
      } else if (event.getSource() == generalHelp) {
         new HelpFrame();
      }
    }   
    
    
    // Additional methods for running as an application and window event handling.
    
    public static void main(String argv[]) {
      accSimulator ac = new accSimulator(argv);
      Messenger.setParent(ac);
      Messenger.setProperties(new Properties());
    }
    
    public void windowClosing( WindowEvent event ) {
       System.exit(0);
    }
   
    public void windowClosed( WindowEvent event ) {
    }
   
    public void windowDeiconified( WindowEvent event ) {}
   
    public void windowIconified( WindowEvent event ) {}
   
   
public void windowDeactivated( WindowEvent event ) {}
   
    public void windowActivated( WindowEvent event ) {}
   
    public void windowOpened( WindowEvent event ) {}


}

